Alibaba Cloud Technology Stack

Primary cloud infrastructure for China deployment

AI/ML Services

Qwen via Model Studio

LLM Provider (Qwen 2.5, Qwen-Max)

gte-Qwen2 via DashScope

Embedding Service (top MTEB)

gte-rerank via DashScope

Reranker for RAG optimization

Platform Services

API Gateway

Traffic control, OAuth2/OIDC

ACK (Container Service)

Kubernetes for custom services

Data Services

AnalyticDB for PostgreSQL

Vector DB with FastANN engine

Alibaba Cloud OSS

Document storage (12 nines)

ApsaraDB RDS PostgreSQL

Metadata database

Elasticsearch

Hybrid semantic + keyword search

Alibaba Cloud GDB

Graph DB for relationships

Integration Services

DataWorks

ETL platform with governance

MQ for Apache Kafka

Event-driven ingestion

Microsoft (Retained)

Azure AD

SSO, Identity, RBAC source

MS Graph API

SharePoint, OneDrive, Outlook

Microsoft 365

Office productivity suite